[Git][NTPsec/ntpsec][master] spelling fixes

Gary E. Miller gitlab at mg.gitlab.com
Wed Jan 4 23:33:38 UTC 2017


Gary E. Miller pushed to branch master at NTPsec / ntpsec


Commits:
ea9b6882 by klemens at 2017-01-04T15:31:40-08:00
spelling fixes

Signed-off-by: Gary E. Miller <gem at rellim.com>

- - - - -


18 changed files:

- devel/tour.txt
- docs/includes/ntpq-body.txt
- include/icom.h
- ntpclients/ntpviz
- ntpd/ntp_proto.c
- ntpd/ntp_restrict.c
- ntpd/ntp_timer.c
- ntpd/refclock_arbiter.c
- ntpd/refclock_generic.c
- ntpd/refclock_gpsd.c
- ntpd/refclock_jjy.c
- ntpd/refclock_modem.c
- ntpd/refclock_neoclock.c
- ntpd/refclock_nmea.c
- ntpd/refclock_oncore.c
- ntpfrob/precision.c
- tests/check_y2k.c
- tests/ntpd/leapsec.c


Changes:

=====================================
devel/tour.txt
=====================================
--- a/devel/tour.txt
+++ b/devel/tour.txt
@@ -443,7 +443,7 @@ and time-out/panic logic.
 
 ntpmon is simpler.  It's a basic TUI modeled on Unix top(1), mutt(1)
 and similar programs.  It just calls some of the ControlSession
-methods repeatedly, formating what it gets back as a live display.
+methods repeatedly, formatting what it gets back as a live display.
 
 The code for making the actual displays in htpq and ntpmon mostly
 doesn't live in the front end.  It's in ntp.util, well separated from


=====================================
docs/includes/ntpq-body.txt
=====================================
--- a/docs/includes/ntpq-body.txt
+++ b/docs/includes/ntpq-body.txt
@@ -181,7 +181,7 @@ following.
 
 +raw+::
   Display server messages as received and without reformatting.
-  The only formating/interpretation done on the data is
+  The only formatting/interpretation done on the data is
   to transform nonascii data into a printable (but barely
   understandable) form.
 


=====================================
include/icom.h
=====================================
--- a/include/icom.h
+++ b/include/icom.h
@@ -7,7 +7,7 @@
  * Common definitions
  */
 #define P_ERMSG	0x1		/* trace bus error messages */
-#define P_TRACE 0x2		/* trace CI-V messges */
+#define P_TRACE 0x2		/* trace CI-V messages */
 #define RETRY	3		/* max packet retries */
 #define IBAUD	B1200		/* autotune port speed */
 


=====================================
ntpclients/ntpviz
=====================================
--- a/ntpclients/ntpviz
+++ b/ntpclients/ntpviz
@@ -671,7 +671,7 @@ gpsd log file is created by the gps-log program.</p>
 
         # grab and sort the values, no need for the timestamp, etc.
 
-        # compute freqency offset
+        # compute frequency offset
         values = [float(line[2]) for line in self.loopstats]
         stats = VizStats(values, "Local Clock Frequency Offset", freq=1,)
 
@@ -746,7 +746,7 @@ line at 0ppm.  Expected values of 99%-1% percentiles: 0.4ppm</p>
             exp = """\
 <p>This shows the RMS Frequency Jitter (aka wander) of the local
 clock's frequency.  In other words, how fast the local clock changes
-freqency.</p>
+frequency.</p>
 
 <p>Lower is better.  An ideal clock would be a horizontal line at
 0ppm.</p>


=====================================
ntpd/ntp_proto.c
=====================================
--- a/ntpd/ntp_proto.c
+++ b/ntpd/ntp_proto.c
@@ -193,7 +193,7 @@ is_control_packet(
 
 /* Free a parsed_pkt structure allocated by parsed_packet(). In the
    event of a parse error, this function may be called from within
-   parse_packet() while the structure is only partially initalized, so
+   parse_packet() while the structure is only partially initialized, so
    we must be careful not to dereference uninitialized pointers.  This
    is achieved by making sure we use calloc() everywhere in
    parse_packet(), and then comparing to NULL before dereferencing.


=====================================
ntpd/ntp_restrict.c
=====================================
--- a/ntpd/ntp_restrict.c
+++ b/ntpd/ntp_restrict.c
@@ -38,7 +38,7 @@
  */
 /*
  * We will use two lists, one for IPv4 addresses and one for IPv6
- * addresses. This is not protocol-independant but for now I can't
+ * addresses. This is not protocol-independent but for now I can't
  * find a way to respect this. We'll check this later... JFB 07/2001
  */
 #define MASK_IPV6_ADDR(dst, src, msk)					\


=====================================
ntpd/ntp_timer.c
=====================================
--- a/ntpd/ntp_timer.c
+++ b/ntpd/ntp_timer.c
@@ -522,7 +522,7 @@ check_leapsec(
 	 * we let the normal clock correction take over, even if a jump
 	 * is involved.
          * Also make sure the alarming events are edge-triggered, that is,
-         * ceated only when the threshold is crossed.
+         * created only when the threshold is crossed.
          */
 	if (  (leapsec > 0 || lsprox < LSPROX_ALERT)
 	    && leapsec < lsprox                     ) {


=====================================
ntpd/refclock_arbiter.c
=====================================
--- a/ntpd/refclock_arbiter.c
+++ b/ntpd/refclock_arbiter.c
@@ -266,7 +266,7 @@ arb_receive(
 	if (up->tcswitch == 0) {
 
 		/*
-		 * Collect statistics. If nothing is recogized, just
+		 * Collect statistics. If nothing is recognized, just
 		 * ignore; sometimes the clock doesn't stop spewing
 		 * timecodes for awhile after the B0 command.
 		 *


=====================================
ntpd/refclock_generic.c
=====================================
--- a/ntpd/refclock_generic.c
+++ b/ntpd/refclock_generic.c
@@ -4479,8 +4479,8 @@ trimbletaip_event(
  * sendcmd, sendbyte, sendetx, sendflt, sendint implement the command
  * interface to the receiver.
  *
- * CAVEAT: the sendflt, sendint routines are byte order dependend and
- * float implementation dependend - these must be converted to portable
+ * CAVEAT: the sendflt, sendint routines are byte order dependent and
+ * float implementation dependent - these must be converted to portable
  * versions !
  *
  * CURRENT LIMITATION: float implementation. This runs only on systems


=====================================
ntpd/refclock_gpsd.c
=====================================
--- a/ntpd/refclock_gpsd.c
+++ b/ntpd/refclock_gpsd.c
@@ -562,7 +562,7 @@ gpsd_start(
 	return true;
 
 dev_fail:
-	/* On failure, remove all UNIT ressources and declare defeat. */
+	/* On failure, remove all UNIT resources and declare defeat. */
 
 	INSIST (up);
 	if (!--up->refcount) {
@@ -799,7 +799,7 @@ timer_primary(
 	int rc;
 
 	/* This is used for timeout handling. Nothing that needs
-	 * sub-second precison happens here, so receive/connect/retry
+	 * sub-second precision happens here, so receive/connect/retry
 	 * timeouts are simply handled by a count down, and then we
 	 * decide what to do by the socket values.
 	 *
@@ -1126,7 +1126,7 @@ json_token_skip(
 	if (tid >= 0 && tid < ctx->ntok) {
 		int len = ctx->tok[tid].size;
 		/* For arrays and objects, the size is the number of
-		 * ITEMS in the compound. Thats the number of objects in
+		 * ITEMS in the compound. That's the number of objects in
 		 * the array, and the number of key/value pairs for
 		 * objects. In theory, the key must be a string, and we
 		 * could simply skip one token before skipping the
@@ -1605,7 +1605,7 @@ process_pps(
 	++up->tc_pps_recv;
 
 	/* Bail out if there's indication that time sync is bad or
-	 * if we're explicitely requested to ignore PPS data.
+	 * if we're explicitly requested to ignore PPS data.
 	 */
 	if (up->fl_nosync)
 		return;


=====================================
ntpd/refclock_jjy.c
=====================================
--- a/ntpd/refclock_jjy.c
+++ b/ntpd/refclock_jjy.c
@@ -574,7 +574,7 @@ jjy_receive ( struct recvbuf *rbufp )
 		/* To avoid its claim, pass the value BMAX-1. */
 
 		/*
-		 * Append received charaters to temporary buffer
+		 * Append received characters to temporary buffer
 		 */
 		for ( i = 0 ;
 		      i < pp->lencode && up->iRawBufLen < MAX_RAWBUF - 2 ;
@@ -658,7 +658,7 @@ jjy_receive ( struct recvbuf *rbufp )
 				iBreakPosition = up->iRawBufLen - 1 ;
 			}
 
-			/* Copy charaters from temporary buffer to process buffer */
+			/* Copy characters from temporary buffer to process buffer */
 			up->iLineBufLen = up->iTextBufLen = 0 ;
 			for ( i = iReadRawBuf ; i <= iBreakPosition ; i ++ ) {
 
@@ -1266,7 +1266,7 @@ jjy_receive_tristate_jjy01 ( struct recvbuf *rbufp )
 
 		if ( up->iTimestamp[1] - 2 <= up->iTimestamp[0]
 		  && up->iTimestamp[0]     <= up->iTimestamp[1] ) {
-			/* 3 commands (time,date,stim) was excuted in two seconds */
+			/* 3 commands (time,date,stim) was executed in two seconds */
 			jjy_synctime( peer, pp, up ) ;
 			return JJY_RECEIVE_DONE ;
 		} else if ( up->iTimestamp[0] > up->iTimestamp[1] ) {
@@ -2151,7 +2151,7 @@ jjy_receive_tristate_gpsclock01 ( struct recvbuf *rbufp )
 
 		if ( up->iTimestamp[1] - 2 <= up->iTimestamp[0]
 		  && up->iTimestamp[0]     <= up->iTimestamp[1] ) {
-			/* 3 commands (time,date,stim) was excuted in two seconds */
+			/* 3 commands (time,date,stim) was executed in two seconds */
 			jjy_synctime( peer, pp, up ) ;
 			return JJY_RECEIVE_DONE ;
 		} else if ( up->iTimestamp[0] > up->iTimestamp[1] ) {


=====================================
ntpd/refclock_modem.c
=====================================
--- a/ntpd/refclock_modem.c
+++ b/ntpd/refclock_modem.c
@@ -422,7 +422,7 @@ modem_message(
 	/*
 	 * We are waiting for the CONNECT response to the dial
 	 * command. When this happens, listen for timecodes. If
-	 * somthing other than CONNECT is received, like BUSY
+	 * something other than CONNECT is received, like BUSY
 	 * or NO CARRIER, abort the call.
 	 */
 	case S_CONNECT:
@@ -705,7 +705,7 @@ modem_timer(
 	UNUSED_ARG(unit);
 
 	/*
-	 * This routine implments a timeout which runs for a programmed
+	 * This routine implements a timeout which runs for a programmed
 	 * interval. The counter is initialized by the state machine and
 	 * counts down to zero. Upon reaching zero, the state machine is
 	 * called. If flag1 is set while timer is zero, force a call.


=====================================
ntpd/refclock_neoclock.c
=====================================
--- a/ntpd/refclock_neoclock.c
+++ b/ntpd/refclock_neoclock.c
@@ -240,7 +240,7 @@ neoclock4x_start(int unit,
    * no fudge time is given by user!
    * use 169.583333 ms to compensate the serial line delay
    * formula is:
-   * 2400 Baud / 11 bit = 218.18 charaters per second
+   * 2400 Baud / 11 bit = 218.18 characters per second
    *  (NeoClock4X timecode len)
    */
   pp->fudgetime1 = (NEOCLOCK4X_TIMECODELEN * 11) / 2400.0;
@@ -1029,7 +1029,7 @@ neol_check_firmware(int unit,
  *
  * 2006/01/11 cjh
  * Revision 1.15
- * - remove some unsued #ifdefs
+ * - remove some unused #ifdefs
  * - fix nsec calculation, closes #499
  *
  * 2009/12/04 cjh


=====================================
ntpd/refclock_nmea.c
=====================================
--- a/ntpd/refclock_nmea.c
+++ b/ntpd/refclock_nmea.c
@@ -318,7 +318,7 @@ static void     save_ltc        (struct refclockproc * const, const char * const
 				 size_t);
 
 /*
- * If we want the driver to ouput sentences, too: re-enable the send
+ * If we want the driver to output sentences, too: re-enable the send
  * support functions by defining NMEA_WRITE_SUPPORT to non-zero...
  */
 #if NMEA_WRITE_SUPPORT


=====================================
ntpd/refclock_oncore.c
=====================================
--- a/ntpfrob/precision.c
+++ b/ntpfrob/precision.c
@@ -45,7 +45,7 @@ void precision(const iomode mode)
  *      ELSE    this machine has resolution < time to read clock
  *
  * SO: if it exits on the first loop, assume "full accuracy" (1us)
- *     otherwise, take the log2(observered difference, rounded UP)
+ *     otherwise, take the log2(observed difference, rounded UP)
  *
  * MINLOOPS > 1 ensures that even if there is a STEP between the initial call
  * and the first loop, it doesn't stop too early.


=====================================
tests/check_y2k.c
=====================================
--- a/tests/check_y2k.c
+++ b/tests/check_y2k.c
@@ -60,7 +60,7 @@ Days ( int Year )		/* return number of days since year "0" */
 {
     long  Return;
 		/* this is a known to be good algorithm */
-    Return = Year * 365;	/* first aproximation to the value */
+    Return = Year * 365;	/* first approximation to the value */
     if ( Year >= 1 )
     {		/* see notes in libparse/parse.c if you want a PROPER
 		 * **generic algorithm. */


=====================================
tests/ntpd/leapsec.c
=====================================
--- a/tests/ntpd/leapsec.c
+++ b/tests/ntpd/leapsec.c
@@ -550,7 +550,7 @@ TEST(leapsec, ls2009limdata) {
 	rc = setup_load_table(leap1, 1);
 	TEST_ASSERT_TRUE(rc);
 
-	// test on-spot with limted table - does not work if build before 2013!
+	// test on-spot with limited table - does not work if build before 2013!
 	rc = leapsec_query(&qr, lsec2009, NULL);
 	TEST_ASSERT_FALSE(rc);
 	TEST_ASSERT_EQUAL(35, qr.tai_offs);



View it on GitLab: https://gitlab.com/NTPsec/ntpsec/commit/ea9b688295a9205f8b02c2c98bf9f537b09e507f
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <https://lists.ntpsec.org/pipermail/vc/attachments/20170104/f6320051/attachment.html>


More information about the vc mailing list
--- a/ntpd/refclock_oncore.c
+++ b/ntpd/refclock_oncore.c
@@ -1136,12 +1136,12 @@ oncore_read_config(
  *
  *	There is an optional line, starting with DELAY, followed
  *	   by 1 or two fields.	The first is a number (a time) the second is
  *	   'MS', 'US' or 'NS' for miliseconds, microseconds or nanoseconds.
  *	    DELAY  is cable delay, typically a few tens of ns.
  *
  *	There is an optional line, starting with OFFSET, followed
  *	   by 1 or two fields.	The first is a number (a time) the second is
  *	   'MS', 'US' or 'NS' for miliseconds, microseconds or nanoseconds.
  *	   OFFSET is the offset of the PPS pulse from 0. (only fully implemented
  *		with the PPSAPI, we need to be able to tell the Kernel about this
  *		offset if the Kernel PLL is in use, but can only do this presently
@@ -1283,7 +1283,7 @@ oncore_read_config(
 				f1 = -f1;
 				sign = -1;
 			}
-			instance->ss_lat = sign*1000*(fabs(f3) + 60*(fabs(f2) + 60*f1)); /*miliseconds*/
+			instance->ss_lat = sign*1000*(fabs(f3) + 60*(fabs(f2) + 60*f1)); /*milliseconds*/
 			lat_flg++;
 		} else if (!strncmp(cc, "LON", (size_t) 3)) {
 			f1 = f2 = f3 = 0;
@@ -1293,7 +1293,7 @@ oncore_read_config(
 				f1 = -f1;
 				sign = -1;
 			}
-			instance->ss_long = sign*1000*(fabs(f3) + 60*(fabs(f2) + 60*f1)); /*miliseconds*/
+			instance->ss_long = sign*1000*(fabs(f3) + 60*(fabs(f2) + 60*f1)); /*milliseconds*/
 			long_flg++;
 		} else if (!strncmp(cc, "HT", (size_t) 2)) {
 			f1 = 0;
@@ -1136,12 +1136,12 @@ oncore_read_config(
  *	There is an optional line, starting with DELAY, followed
  *	   by 1 or two fields.	The first is a number (a time) the second is
- *	   'MS', 'US' or 'NS' for miliseconds, microseconds or nanoseconds.
+ *	   'MS', 'US' or 'NS' for milliseconds, microseconds or nanoseconds.
  *	    DELAY  is cable delay, typically a few tens of ns.
  *
@@ -1136,12 +1136,12 @@ oncore_read_config(
  *	There is an optional line, starting with OFFSET, followed
  *	   by 1 or two fields.	The first is a number (a time) the second is
- *	   'MS', 'US' or 'NS' for miliseconds, microseconds or nanoseconds.
+ *	   'MS', 'US' or 'NS' for milliseconds, microseconds or nanoseconds.
  *	   OFFSET is the offset of the PPS pulse from 0. (only fully implemented
  *		with the PPSAPI, we need to be able to tell the Kernel about this


=====================================
ntpfrob/precision.c
=====================================